.. expect: default role used (hint: for inline literals, use double backticks) (default-role)

.. c:function:: void PyThread_tss_free(Py_tss_t *key)

   Even if hidden in a function, this default-role should be spotted:
   `NULL`.
